==> estateplat-common-1.1.0-20161207.133344-225-sources.jar: cn/gtmap/estateplat/model/server/core/DjsjNydDcb.java <==
package cn.gtmap.estateplat.model.server.core;

import java.util.Date;

/**
 * Created by IntelliJ IDEA.
 * User: sc
 * Date: 15-5-8
 * Time: 上午9:33
 * To change this template use File | Settings | File Templates
 * doc:农用地调查表.
 */
public class DjsjNydDcb {
    private String djh;
    private String zdsz;
    private String tdzl;
    private String sztfh;
    private String qsxz;
    private String syqlx;
    private String tdyt;
    private String pzyt;
    private Double scmj;
    private Double fzmj;
    private Double jzrjl;
    private Double jzmd;
    private String tdjb;
    private Double qdjg;
    private Date qsrq;
    private Date zzrq;
    private String bz;
    private String zdzmj;
    private String jzzmj;
    private String pzmj;
    private String synx;
    private Integer dwxz;
    private String gmjjhyfldm;
    private String sjyt;
    private String gysyqqh;
    private String txdz;
    private String blc;
    private String zd_djdcb_index;
    private String bdcdyh;
    private Double jzxg;
    private String bdclxxx;
    private String ybdjh;
    private String tdsyzmc;
    private String mjdw;
    private String qlsdfs;

    public String getTdsyzmc() {
        return tdsyzmc;
    }

    public void setTdsyzmc(String tdsyzmc) {
        this.tdsyzmc = tdsyzmc;
    }

    public String getDjh() {
        return djh;
    }

    public void setDjh(String djh) {
        this.djh = djh;
    }

    public String getZdsz() {
        return zdsz;
    }

    public void setZdsz(String zdsz) {
        this.zdsz = zdsz;
    }

    public String getTdzl() {
        return tdzl;
    }

    public void setTdzl(String tdzl) {
        this.tdzl = tdzl;
    }

    public String getSztfh() {
        return sztfh;
    }

    public void setSztfh(String sztfh) {
        this.sztfh = sztfh;
    }

    public String getQsxz() {
        return qsxz;
    }

    public void setQsxz(String qsxz) {
        this.qsxz = qsxz;
    }

    public String getSyqlx() {
        return syqlx;
    }

    public void setSyqlx(String syqlx) {
        this.syqlx = syqlx;
    }

    public String getTdyt() {
        return tdyt;
    }

    public void setTdyt(String tdyt) {
        this.tdyt = tdyt;
    }

    public String getPzyt() {
        return pzyt;
    }

    public void setPzyt(String pzyt) {
        this.pzyt = pzyt;
    }

    public Double getScmj() {
        return scmj;
    }

    public void setScmj(Double scmj) {
        this.scmj = scmj;
    }

    public Double getFzmj() {
        return fzmj;
    }

    public void setFzmj(Double fzmj) {
        this.fzmj = fzmj;
    }

    public Double getJzrjl() {
        return jzrjl;
    }

    public void setJzrjl(Double jzrjl) {
        this.jzrjl = jzrjl;
    }

    public Double getJzmd() {
        return jzmd;
    }

    public void setJzmd(Double jzmd) {
        this.jzmd = jzmd;
    }

    public String getTdjb() {
        return tdjb;
    }

    public void setTdjb(String tdjb) {
        this.tdjb = tdjb;
    }

    public Double getQdjg() {
        return qdjg;
    }

    public void setQdjg(Double qdjg) {
        this.qdjg = qdjg;
    }

    public Date getQsrq() {
        return qsrq;
    }

    public void setQsrq(Date qsrq) {
        this.qsrq = qsrq;
    }

    public Date getZzrq() {
        return zzrq;
    }

    public void setZzrq(Date zzrq) {
        this.zzrq = zzrq;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getZdzmj() {
        return zdzmj;
    }

    public void setZdzmj(String zdzmj) {
        this.zdzmj = zdzmj;
    }

    public String getJzzmj() {
        return jzzmj;
    }

    public void setJzzmj(String jzzmj) {
        this.jzzmj = jzzmj;
    }

    public String getPzmj() {
        return pzmj;
    }

    public void setPzmj(String pzmj) {
        this.pzmj = pzmj;
    }

    public String getSynx() {
        return synx;
    }

    public void setSynx(String synx) {
        this.synx = synx;
    }

    public Integer getDwxz() {
        return dwxz;
    }

    public void setDwxz(Integer dwxz) {
        this.dwxz = dwxz;
    }

    public String getGmjjhyfldm() {
        return gmjjhyfldm;
    }

    public void setGmjjhyfldm(String gmjjhyfldm) {
        this.gmjjhyfldm = gmjjhyfldm;
    }

    public String getSjyt() {
        return sjyt;
    }

    public void setSjyt(String sjyt) {
        this.sjyt = sjyt;
    }

    public String getGysyqqh() {
        return gysyqqh;
    }

    public void setGysyqqh(String gysyqqh) {
        this.gysyqqh = gysyqqh;
    }

    public String getTxdz() {
        return txdz;
    }

    public void setTxdz(String txdz) {
        this.txdz = txdz;
    }

    public String getBlc() {
        return blc;
    }

    public void setBlc(String blc) {
        this.blc = blc;
    }

    public String getZd_djdcb_index() {
        return zd_djdcb_index;
    }

    public void setZd_djdcb_index(String zd_djdcb_index) {
        this.zd_djdcb_index = zd_djdcb_index;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public Double getJzxg() {
        return jzxg;
    }

    public void setJzxg(Double jzxg) {
        this.jzxg = jzxg;
    }

    public String getBdclxxx() {
        return bdclxxx;
    }

    public void setBdclxxx(String bdclxxx) {
        this.bdclxxx = bdclxxx;
    }

    public String getYbdjh() {
        return ybdjh;
    }

    public void setYbdjh(String ybdjh) {
        this.ybdjh = ybdjh;
    }

    public String getMjdw() {
        return mjdw;
    }

    public void setMjdw(String mjdw) {
        this.mjdw = mjdw;
    }

    public String getQlsdfs() {
        return qlsdfs;
    }

    public void setQlsdfs(String qlsdfs) {
        this.qlsdfs = qlsdfs;
    }
}

==> estateplat-common-1.2.4-20210122.015326-632-sources.jar: cn/gtmap/estateplat/model/server/core/DjsjNydDcb.java <==
package cn.gtmap.estateplat.model.server.core;

import java.util.Date;

/**
 * Created by IntelliJ IDEA.
 * User: sc
 * Date: 15-5-8
 * Time: 上午9:33
 * To change this template use File | Settings | File Templates
 * doc:农用地调查表.
 */
public class DjsjNydDcb {
    private String djh;
    private String zdsz;
    private String tdzl;
    private String sztfh;
    private String qsxz;
    private String syqlx;
    private String tdyt;
    private String pzyt;
    private Double scmj;
    private Double fzmj;
    private Double jzrjl;
    private Double jzmd;
    private String tdjb;
    private Double qdjg;
    private Date qsrq;
    private Date zzrq;
    private String bz;
    private String zdzmj;
    private String jzzmj;
    private String pzmj;
    private String synx;
    private Integer dwxz;
    private String gmjjhyfldm;
    private String sjyt;
    private String gysyqqh;
    private String txdz;
    private String blc;
    private String zd_djdcb_index;
    private String bdcdyh;
    private Double jzxg;
    private String bdclxxx;
    private String ybdjh;
    private String tdsyzmc;
    private String mjdw;
    private String qlsdfs;
    /**
     * @author <a href="mailto:yulei1@gtmap.cn">yulei</a>
     * @description 等级
     */
    private String dj;

    public String getTdsyzmc() {
        return tdsyzmc;
    }

    public void setTdsyzmc(String tdsyzmc) {
        this.tdsyzmc = tdsyzmc;
    }

    public String getDjh() {
        return djh;
    }

    public void setDjh(String djh) {
        this.djh = djh;
    }

    public String getZdsz() {
        return zdsz;
    }

    public void setZdsz(String zdsz) {
        this.zdsz = zdsz;
    }

    public String getTdzl() {
        return tdzl;
    }

    public void setTdzl(String tdzl) {
        this.tdzl = tdzl;
    }

    public String getSztfh() {
        return sztfh;
    }

    public void setSztfh(String sztfh) {
        this.sztfh = sztfh;
    }

    public String getQsxz() {
        return qsxz;
    }

    public void setQsxz(String qsxz) {
        this.qsxz = qsxz;
    }

    public String getSyqlx() {
        return syqlx;
    }

    public void setSyqlx(String syqlx) {
        this.syqlx = syqlx;
    }

    public String getTdyt() {
        return tdyt;
    }

    public void setTdyt(String tdyt) {
        this.tdyt = tdyt;
    }

    public String getPzyt() {
        return pzyt;
    }

    public void setPzyt(String pzyt) {
        this.pzyt = pzyt;
    }

    public Double getScmj() {
        return scmj;
    }

    public void setScmj(Double scmj) {
        this.scmj = scmj;
    }

    public Double getFzmj() {
        return fzmj;
    }

    public void setFzmj(Double fzmj) {
        this.fzmj = fzmj;
    }

    public Double getJzrjl() {
        return jzrjl;
    }

    public void setJzrjl(Double jzrjl) {
        this.jzrjl = jzrjl;
    }

    public Double getJzmd() {
        return jzmd;
    }

    public void setJzmd(Double jzmd) {
        this.jzmd = jzmd;
    }

    public String getTdjb() {
        return tdjb;
    }

    public void setTdjb(String tdjb) {
        this.tdjb = tdjb;
    }

    public Double getQdjg() {
        return qdjg;
    }

    public void setQdjg(Double qdjg) {
        this.qdjg = qdjg;
    }

    public Date getQsrq() {
        return qsrq;
    }

    public void setQsrq(Date qsrq) {
        this.qsrq = qsrq;
    }

    public Date getZzrq() {
        return zzrq;
    }

    public void setZzrq(Date zzrq) {
        this.zzrq = zzrq;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getZdzmj() {
        return zdzmj;
    }

    public void setZdzmj(String zdzmj) {
        this.zdzmj = zdzmj;
    }

    public String getJzzmj() {
        return jzzmj;
    }

    public void setJzzmj(String jzzmj) {
        this.jzzmj = jzzmj;
    }

    public String getPzmj() {
        return pzmj;
    }

    public void setPzmj(String pzmj) {
        this.pzmj = pzmj;
    }

    public String getSynx() {
        return synx;
    }

    public void setSynx(String synx) {
        this.synx = synx;
    }

    public Integer getDwxz() {
        return dwxz;
    }

    public void setDwxz(Integer dwxz) {
        this.dwxz = dwxz;
    }

    public String getGmjjhyfldm() {
        return gmjjhyfldm;
    }

    public void setGmjjhyfldm(String gmjjhyfldm) {
        this.gmjjhyfldm = gmjjhyfldm;
    }

    public String getSjyt() {
        return sjyt;
    }

    public void setSjyt(String sjyt) {
        this.sjyt = sjyt;
    }

    public String getGysyqqh() {
        return gysyqqh;
    }

    public void setGysyqqh(String gysyqqh) {
        this.gysyqqh = gysyqqh;
    }

    public String getTxdz() {
        return txdz;
    }

    public void setTxdz(String txdz) {
        this.txdz = txdz;
    }

    public String getBlc() {
        return blc;
    }

    public void setBlc(String blc) {
        this.blc = blc;
    }

    public String getZd_djdcb_index() {
        return zd_djdcb_index;
    }

    public void setZd_djdcb_index(String zd_djdcb_index) {
        this.zd_djdcb_index = zd_djdcb_index;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public Double getJzxg() {
        return jzxg;
    }

    public void setJzxg(Double jzxg) {
        this.jzxg = jzxg;
    }

    public String getBdclxxx() {
        return bdclxxx;
    }

    public void setBdclxxx(String bdclxxx) {
        this.bdclxxx = bdclxxx;
    }

    public String getYbdjh() {
        return ybdjh;
    }

    public void setYbdjh(String ybdjh) {
        this.ybdjh = ybdjh;
    }

    public String getMjdw() {
        return mjdw;
    }

    public void setMjdw(String mjdw) {
        this.mjdw = mjdw;
    }

    public String getQlsdfs() {
        return qlsdfs;
    }

    public void setQlsdfs(String qlsdfs) {
        this.qlsdfs = qlsdfs;
    }

    public String getDj() {
        return dj;
    }

    public void setDj(String dj) {
        this.dj = dj;
    }
}
